==> style-o-matic-1.1.5.tgz: package/es/components/ToolBar/ToolBarTitle.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import ReactDOM from "react-dom";
import { CoreComponent, getValidProps, getElementType, setCorePropDefaults, ROLE } from "../../lib";

var ToolBarTitle = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBarTitle, _CoreComponent);

  function ToolBarTitle() {
    _classCallCheck(this, ToolBarTitle);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var _this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args)));

    _this.onEventDispatch = function (eventName, eventData, eventSenders) {
      if (eventName === "scroll" && _this.node) {
        var _this$props = _this.props,
            text = _this$props.text,
            children = _this$props.children;

        var currentTitle = text || children;
        var newTitle = "";
        for (var i = 0; i < eventSenders.length; i += 1) {
          var sender = eventSenders[i];
          if (sender) {
            var scrollTop = _this.node.offsetParent.scrollTop;
            var _this$node = _this.node,
                offsetTop = _this$node.offsetTop,
                clientHeight = _this$node.clientHeight;

            var targetOffset = offsetTop + clientHeight;
            var pageOffset = scrollTop + 70;
            var titleText = sender.props.children;
            if (scrollTop > 0 && targetOffset < pageOffset) {
              newTitle = titleText;
            }
          }
        }
        if (currentTitle !== newTitle) {
          _this.setState({ dynamicText: newTitle });
        }
      }
    };

    _this.state = {
      dynamicText: null
    };
    return _this;
  }

  ToolBarTitle.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        text = _getValidProps.text,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var dynamicText = this.state.dynamicText;


    var ElementType = getElementType(ToolBarTitle, this.props);
    var titleText = dynamicText || text || children;

    return React.createElement(
      ElementType,
      props,
      titleText
    );
  };

  return ToolBarTitle;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.TITLE,
  text: ""
}), _temp);


export default ToolBarTitle;

==> style-o-matic-1.1.37.tgz: package/es/components/ToolBar/ToolBarTitle.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import ReactDOM from "react-dom";
import { CoreComponent, getValidProps, getElementType, getCorePropDefaults, ROLE } from "../../lib";

var ToolBarTitle = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBarTitle, _CoreComponent);

  function ToolBarTitle() {
    _classCallCheck(this, ToolBarTitle);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var _this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args)));

    _this.onEventDispatch = function (eventName, eventData, eventSenders) {
      if (eventName === "scroll" && _this.node) {
        var _this$props = _this.props,
            text = _this$props.text,
            children = _this$props.children;

        var currentTitle = text || children;
        var newTitle = "";
        for (var i = 0; i < eventSenders.length; i += 1) {
          var sender = eventSenders[i];
          if (sender) {
            var scrollTop = _this.node.offsetParent.scrollTop;
            var _this$node = _this.node,
                offsetTop = _this$node.offsetTop,
                clientHeight = _this$node.clientHeight;

            var targetOffset = offsetTop + clientHeight;
            var pageOffset = scrollTop + 70;
            var titleText = sender.props.children;
            if (scrollTop > 0 && targetOffset < pageOffset) {
              newTitle = titleText;
            }
          }
        }
        if (currentTitle !== newTitle) {
          _this.setState({ dynamicText: newTitle });
        }
      }
    };

    _this.state = {
      dynamicText: null
    };
    return _this;
  }

  ToolBarTitle.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        text = _getValidProps.text,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var dynamicText = this.state.dynamicText;


    var ElementType = getElementType(ToolBarTitle, this.props);
    var titleText = dynamicText || text || children;

    return React.createElement(
      ElementType,
      props,
      titleText
    );
  };

  return ToolBarTitle;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.TITLE,
  text: ""
}), _temp);


export default ToolBarTitle;
